@@ -12,7 +12,7 @@ use warnings;
 
 package App::Magpie::Action::FixSpec;
 # ABSTRACT: fixspec command implementation
-$App::Magpie::Action::FixSpec::VERSION = '2.008';
+$App::Magpie::Action::FixSpec::VERSION = '2.009';
 use Moose;
 use Parse::CPAN::Meta   1.4401; # load_file
 use Path::Tiny;
@@ -86,7 +86,7 @@ sub run {
 
     # cleaning spec file
     $self->log_debug( "adding %{?perl_default_filter}" );
-    $spec =~ s/^Name:/%{?perl_default_filter}\n\nName:/msi;
+    $spec =~ s/^Name:/%{?perl_default_filter}\n\nName:/msi if $spec !~ /perl_default_filter/;
 
     $self->log_debug( "removing mandriva macros" );
     $spec =~ s/^%if %{mdkversion}.*?^%endif$//msi;
@@ -254,7 +254,7 @@ App::Magpie::Action::FixSpec - fixspec command implementation
 
 =head1 VERSION
 
-version 2.008
+version 2.009
 
 =head1 SYNOPSIS
 
